==> haskell-hunit-1.6.2.0-318-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HUnit
version:              1.6.2.0
visibility:           public
id:                   HUnit-1.6.2.0-JlkHGrwnzdW73OrIAc87UZ
key:                  HUnit-1.6.2.0-JlkHGrwnzdW73OrIAc87UZ
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  c60b1f9268639ae0eca5b5a16b52943a
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HUnit-1.6.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HUnit-1.6.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HUnit-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hunit
hs-libraries:         HSHUnit-1.6.2.0-JlkHGrwnzdW73OrIAc87UZ
depends:
    base-4.17.2.1 call-stack-0.4.0-5KvscC3Q9W36Bo4hk8AMEN
    deepseq-1.4.8.0

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hunit-1.6.2.0-348-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HUnit
version:              1.6.2.0
visibility:           public
id:                   HUnit-1.6.2.0-GnO9wO3IZ0dFnUT6z8aFmA
key:                  HUnit-1.6.2.0-GnO9wO3IZ0dFnUT6z8aFmA
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  b286fd6e732b5721707e0f3427000e60
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HUnit-1.6.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HUnit-1.6.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HUnit-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hunit
hs-libraries:         HSHUnit-1.6.2.0-GnO9wO3IZ0dFnUT6z8aFmA
depends:
    base-4.17.2.1 call-stack-0.4.0-GLZYnk9HL8J8EgKDjlcntK
    deepseq-1.4.8.0

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
